/***************************************************************
 * Name:      wximagepanel.h
 * Purpose:   ...
 * Author:    Daniel Nell (daniel.nell@nellresearch.de)
 * Created:   2011-01-26
 * Copyright: Daniel Nell (www.nellresearch.de)
 * License:   GPL
 **************************************************************/

#ifndef WXIMAGEPANEL_H
#define WXIMAGEPANEL_H


//////////////////////////////////////////////////////////
// Class wxImagePanel
//
/// \brief A panel that can display as list of images
///        (e. g. pages) and scroll.
///
/// ...
class wxImagePanel : public wxScrolledWindow
{
    public:
        /// \brief Standard constructor
        ///
        /// \param poParent     a pointer to the dialog windows's parent window.
        /// \param nId          the window id, default: 1
        /// \param oPos         the window position, default: wxDefaultPosition
        /// \param oSize        the window size, default: wxDefaultSize
        /// \param nStyle       window style (default: wxHSCROLL | wxVSCROLL | wxSUNKEN_BORDER)
        /// \param strName      class name (default: wxT( "wxIViewCanvas" ))
        wxImagePanel( wxWindow *poParent,
                       wxWindowID nId= wxID_ANY,
                       const wxPoint &oPos= wxDefaultPosition,
                       const wxSize &oSize= wxDefaultSize,
                       long nStyle= wxHSCROLL | wxVSCROLL | wxSUNKEN_BORDER,
                       const wxString& strName= wxT( "wxImagePanel" )
                     );

        /// Virtual destructor
        virtual ~wxImagePanel();

        /// \brief Empty the panel.
        virtual void Reset()
        {
            DestroyChildren();
            SetScrollbars( 1, 1, 1, 1 );
            m_nPanelPagesCount= 0;
        }

        /// \brief Add images to the panel.
        ///
        /// \param oImage       ...
        virtual void AddImage( wxImage oImage );

    protected:
         // Member variables
        int m_nPanelPagesCount;             ///< The number of the pages in the pages panel.

        // Options
        int m_nPanelPagesBitmapSize;        ///< ...
        int m_nPanelPagesBitmapSpace;       ///< ...
};

#endif // WXISCANMAIN_H

