/////////////////////////////////////////////////////////////////////////////
// Project:     wxIView
// Purpose:     Complex wxWidgets sample
// Name:        wxoptionsdialog.cpp
// Author:      Daniel Nell
// Created:     2006/02/16
// Copyright:   (c) Daniel Nell
// Licence:     wxWindows licence
// Modified by:
/////////////////////////////////////////////////////////////////////////////

// For compilers that support precompilation, includes "wx/wx.h".
#include <wx/wxprec.h>
#ifndef WX_PRECOMP
   #include <wx/wx.h>
#endif

// Include additional wxWidgets headers.
#include <wx/statline.h>
#include <wx/notebook.h>

// Include private headers.
#include "wxoptionsdialog.h"


//////////////////////////////////////////////////////////
// class wxOptionStaticLine
//
wxOptionStaticLine::wxOptionStaticLine( wxWindow *poWindow )
{
    m_poStaticLine= new wxStaticLine( poWindow );
    if( !m_poStaticLine )
    {
        ::wxLogError( _( "Cannot create static line pseudo option." ) );
        return;
    }
}

bool wxOptionStaticLine::AddToSizer( wxBoxSizer *poSizer )
{
    return m_poStaticLine
           ? (bool)poSizer->Add( m_poStaticLine, 0, wxGROW | wxLEFT | wxRIGHT, 3 )
           : false;
}


//////////////////////////////////////////////////////////
// class wxOptionCheckBox
//
wxOptionCheckBox::wxOptionCheckBox( wxWindow *poWindow, int nId, const wxString &strText, bool *pbValue )
 : wxOptionBase()
{
    m_pbValue= pbValue;
    m_poCheckBox= new wxCheckBox( poWindow, nId, strText );
    if( !m_poCheckBox )
    {
        ::wxLogError( _( "Cannot create checkbox for option." ) );
        return;
    }
    m_poCheckBox->SetValue( *m_pbValue );
}

bool wxOptionCheckBox::AddToSizer( wxBoxSizer *poSizer )
{
    return m_poCheckBox
           ? (bool)poSizer->Add( m_poCheckBox, 0, wxALIGN_LEFT | wxALL, 3 )
           : false;
}

void wxOptionCheckBox::StoreValue()
{
    (*m_pbValue)= m_poCheckBox->GetValue();
}


//////////////////////////////////////////////////////////
// class wxOptionTextBox
//
wxOptionTextBox::wxOptionTextBox( wxWindow *poWindow, int nId, const wxString &strText, wxString *pstrValue, int nWidth )
{
    m_poWindow= poWindow;
    m_strText= strText;
    m_pstrValue= pstrValue;
    m_poTextCtrl= new wxTextCtrl( poWindow, nId, *m_pstrValue, wxDefaultPosition, wxSize( nWidth, -1 ) );
    if( !m_poTextCtrl )
    {
        ::wxLogError( _( "Cannot create textbox for option." ) );
        return;
    }
}

bool wxOptionTextBox::AddToSizer( wxBoxSizer *poSizer )
{
    if( !m_poTextCtrl )
    {
        return false;
    }

    wxBoxSizer *poHSizer= new wxBoxSizer( wxHORIZONTAL );

    if( !poHSizer )
    {
        return false;
    }
    if(    !poHSizer->Add( new wxStaticText( m_poWindow, wxID_ANY, m_strText ), 0,
                           wxALIGN_CENTER_VERTICAL | wxALIGN_LEFT )
        || !poHSizer->Add( m_poTextCtrl, 0,
                           wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT )
    )
    {
        delete poHSizer;
        return false;
    }
    return (bool)poSizer->Add( poHSizer, 0, wxALIGN_RIGHT | wxALL, 3 );
}

void wxOptionTextBox::StoreValue()
{
    (*m_pstrValue)= m_poTextCtrl->GetValue();
}


//////////////////////////////////////////////////////////
// The options dialog
//
BEGIN_EVENT_TABLE( wxOptionsDialog, wxDialog )
    EVT_BUTTON( wxID_OK, wxOptionsDialog::OnOk )
END_EVENT_TABLE()


wxOptionsDialog::wxOptionsDialog( wxWindow *poParentWindow )
  : wxDialog( poParentWindow, -1,
              wxTheApp->GetAppName() + wxT( " - " ) + _( "Options" ),
              wxDefaultPosition,
              wxDefaultSize,
              wxDEFAULT_DIALOG_STYLE ),
    m_nOptionCount( 0 )
{
    // Initialize members. (Nothing to do, yet.)
}

wxOptionsDialog::~wxOptionsDialog()
{
    // Clean up options.
    while( m_nOptionCount > 0 )
    {
        m_nOptionCount--;
        delete m_apoOptions[m_nOptionCount];
    }
}

void wxOptionsDialog::SetupDialog()
{
    // Create layout.
    wxBoxSizer *poSizer= new wxBoxSizer( wxVERTICAL );

    // Create controls.
    for( int i= 0; i < m_nOptionCount; i++ )
    {
        m_apoOptions[i]->AddToSizer( poSizer );
    }
    poSizer->Add( new wxStaticLine( this ), 0, wxGROW | wxLEFT | wxRIGHT, 3 );
    poSizer->Add( CreateButtonSizer( wxOK | wxCANCEL ), 0, wxALIGN_CENTER | wxALL, 5 );

    // Activate.
    SetSizer( poSizer );
    SetAutoLayout( true );
    poSizer->SetSizeHints( this );
    poSizer->Fit( this );
    Centre( wxBOTH | wxCENTRE_ON_SCREEN );
}

bool wxOptionsDialog::AppendOption( wxOptionBase *poOption )
{
    if( !poOption )
    {
        return false;
    }
    if( m_nOptionCount >= WXOPTIONSDIALOGMAXOPTION )
    {
        return false;
    }
    m_apoOptions[m_nOptionCount]= poOption;
    m_nOptionCount++;
    return true;
}

void wxOptionsDialog::OnOk( wxCommandEvent& WXUNUSED( oEvent ) )
{
    // Get values.
    for( int i= 0; i < m_nOptionCount; i++ )
    {
        m_apoOptions[i]->StoreValue();
    }

    // End modal dialog mode and set the return value to 'OK'.
    EndModal( wxID_OK );
}
